<!--
SPDX-FileCopyrightText: AISEC Pentesting Team

SPDX-License-Identifier: CC0-1.0
-->

# Database

This documentation describes the database layout gallia uses for storing its results.

**Work in progress**